package data_manage

import (
	"errors"
	"fmt"
	"hongze/hongze_task/models/data_manage"
	"hongze/hongze_task/utils"
	"rdluck_tools/http"
	"time"
)

//刷新同花顺数据
func RefreshDataFromThs() (err error) {
	defer func() {
		if err != nil {
			fmt.Println("RefreshDataFromThs Err:" + err.Error())
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"失败提醒", "RefreshDataFromThs ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
	}()
	var condition string
	var pars []interface{}
	condition += " AND source=? "
	pars = append(pars, utils.DATA_SOURCE_THS)
	items, err := data_manage.GetEdbInfoByCondition(condition, pars)
	if err != nil {
		return errors.New("GetEdbInfoByCondition:" + err.Error())
	}

	for _, v := range items {
		startDate := v.EndDate.AddDate(0, 0, -3).Format(utils.FormatDate)
		endDate := time.Now().Format(utils.FormatDate)
		err = SyncEdbDataByThs(int64(v.EdbInfoId), v.EdbCode, startDate, endDate)
		if err != nil {
			return errors.New("SyncEdbDataByThs:" + err.Error())
		}
		minDate, maxDate, err := data_manage.GetEdbDataThsMaxOrMinDate(v.EdbInfoId)
		if err != nil {
			return errors.New("GetEdbDataThsMaxOrMinDate:" + err.Error())
		}
		fmt.Println("minDate:" + minDate + ";maxDate:" + maxDate)
		err = data_manage.ModifyEdbDataInfoDate(v.EdbInfoId, maxDate)
		if err != nil {
			return errors.New("ModifyEdbDataInfoDate:" + err.Error())
		}
	}
	return err
}

//刷新万得数据
func RefreshDataFromWind() (err error) {
	defer func() {
		if err != nil {
			fmt.Println("RefreshDataFromWind Err:" + err.Error())
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"失败提醒", "RefreshDataFromWind ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
	}()
	var condition string
	var pars []interface{}
	condition += " AND source=? "
	pars = append(pars, utils.DATA_SOURCE_WIND)
	items, err := data_manage.GetEdbInfoByCondition(condition, pars)
	if err != nil {
		return err
	}

	for k, v := range items {
		fmt.Println("line 67:", k, v.EdbCode)
		startDate := v.EndDate.AddDate(0, 0, -3).Format(utils.FormatDate)
		endDate := time.Now().Format(utils.FormatDate)
		err = SyncEdbDataByWind(int64(v.EdbInfoId), v.EdbCode, startDate, endDate)
		if err != nil {
			return err
		}
		minDate, maxDate, err := data_manage.GetEdbDataWindMaxOrMinDate(v.EdbInfoId)
		if err != nil {
			return err
		}
		fmt.Println("minDate:" + minDate + ";maxDate:" + maxDate)
		err = data_manage.ModifyEdbDataInfoDate(v.EdbInfoId, maxDate)
		if err != nil {
			return err
		}
	}

	return err
}

//刷新彭博数据
func RefreshDataFromPb() (err error) {
	defer func() {
		if err != nil {
			fmt.Println("RefreshDataFromPb Err:" + err.Error())
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"失败提醒", "RefreshDataFromPb ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
	}()
	var condition string
	var pars []interface{}
	condition += " AND source=? "
	pars = append(pars, utils.DATA_SOURCE_PB)
	items, err := data_manage.GetEdbInfoByCondition(condition, pars)
	if err != nil {
		return errors.New("GetEdbInfoByCondition:" + err.Error())
	}

	for _, v := range items {
		startDate := v.EndDate.AddDate(0, 0, -3).Format(utils.FormatDateUnSpace)
		endDate := time.Now().Format(utils.FormatDateUnSpace)
		fmt.Println(startDate, endDate)
		err = SyncEdbDataByPb(int64(v.EdbInfoId), v.EdbCode, startDate, endDate)
		if err != nil {
			return errors.New("SyncEdbDataByPb:" + err.Error())
		}
		minDate, maxDate, err := data_manage.GetEdbDataPbMaxOrMinDate(v.EdbInfoId)
		if err != nil {
			return errors.New("GetEdbDataThsMaxOrMinDate:" + err.Error())
		}
		fmt.Println("minDate:" + minDate + ";maxDate:" + maxDate)
		err = data_manage.ModifyEdbDataInfoDate(v.EdbInfoId, maxDate)
		if err != nil {
			return errors.New("ModifyEdbDataInfoDate:" + err.Error())
		}
	}
	return err
}

func CheckDataInterface() (err error) {
	go func() {
		checkUrl := utils.Hz_Data_Url + `hz_server`
		body, err := http.Get(checkUrl)
		if err != nil {
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"检测数据接口：失败提醒", "CheckDataInterface ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
		result := string(body)
		if result != "1" {
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"检测数据接口：失败提醒", "CheckDataInterface ErrMsg:"+string(body), utils.EmailSendToUsers)
		}
	}()
	return
}

func CheckPbDataInterface() (err error) {
	go func() {
		checkUrl := utils.Hz_Data_PB_Url + `hz_server`
		body, err := http.Get(checkUrl)
		if err != nil {
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"检测数据接口：失败提醒", "CheckPbDataInterface ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
		result := string(body)
		if result != "1" {
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"检测数据接口：失败提醒", "CheckPbDataInterface ErrMsg:"+string(body), utils.EmailSendToUsers)
		}
	}()
	return
}